@@ -52,7 +52,7 @@ as.zoo.timeSeries <- function(x, ...) {
 
 as.zoo.xts <- function(x, ...) {
   y <- coredata(x)
-  if (length(y) == 0) {
+  if (is.null(dim(y)) && length(y) == 0) {
     y <- NULL
   }
   zoo(y, order.by = index(x), ...)
@@ -65,7 +65,7 @@ as.zooreg.xts <- function(x, frequency = NULL, ...) {
 as.zoo.zoo <- function(x, ...) x
 
 as.vector.zoo <- function(x, mode = "any")
-	as.vector(as.matrix(x), mode = mode)
+	as.vector(coredata(x), mode = mode)
 
 as.matrix.zoo <- function(x, ...) 
 {
